Beaker
======

This workspace contains the basic tasks for provisioning and teardown of beaker clusters

beaker-new
==========
Provisions a new beaker instance

beaker-family
============
Provisions a family of RHEL7 beaker instances
